@@ -1,16 +1,3 @@
-static void par_redo_stack (pTHX_ void *data) {
-#if PERL_VERSION > 10
-    PUSHEVAL((&cxstack[0]) , "");
-#else
-    PUSHEVAL((&cxstack[0]) , "", Nullgv);
-#endif
-}
-
-XS(XS_Internals_PAR_CLEARSTACK) {
-    dounwind(-1);
-    SAVEDESTRUCTOR_X(par_redo_stack, 0);
-}
-
 XS(XS_Internals_PAR_BOOT) {
     GV* tmpgv;
     AV* tmpav;
@@ -104,18 +91,11 @@ XS(XS_Internals_PAR_BOOT) {
         stmpdir = par_mktmpdir( fakeargv );
         if ( !stmpdir ) 
             croak("Unable to create cache directory");
-#ifndef WIN32
-        i = execvp(SvPV_nolen(GvSV(tmpgv)), fakeargv);
-        croak("%s: execution of %s failed (errno=%i)\n", 
-              fakeargv[0], SvPV_nolen(GvSV(tmpgv)), i);
-        return;
-#endif
     }
     i = PerlDir_mkdir(stmpdir, 0700);
     if ( (i != 0) && (i != EEXIST) && (i != -1) ) {
         croak("%s: creation of private cache subdirectory %s failed (errno=%i)\n", 
               fakeargv[0], stmpdir, i);
-        return;
     }
 }
 
@@ -123,7 +103,4 @@ static void par_xs_init(pTHX)
 {
     xs_init(aTHX);
     newXSproto("Internals::PAR::BOOT", XS_Internals_PAR_BOOT, "", "");
-#ifdef PAR_CLEARSTACK
-    newXSproto("Internals::PAR::CLEARSTACK", XS_Internals_PAR_CLEARSTACK, "", "");
-#endif
 }
